### R code from vignette source 'aBioMarVsuit.Rnw'

###################################################
### code chunk number 1: config
###################################################
options(width = 80)
options(continue=" ")
options(prompt="R> ")
set.seed(123)



###################################################
### code chunk number 2: loadPackage
###################################################
library(aBioMarVsuit)


###################################################
### code chunk number 3: aBioMarVsuit.Rnw:77-95
###################################################
data(exprLym)

GexprMatrix<-exprs(exprLym)
SurvData<-pData(exprLym)

PatietId<-rownames(SurvData[!is.na(SurvData[,c("IPI")]),])
Gdata<-GexprMatrix[,PatietId]
dim(Gdata)

SurvTime<-SurvData[!is.na(SurvData[,c("IPI")]),c("FollowUpYears")]
Censor<-ifelse(SurvData[!is.na(SurvData[,c("IPI")]),c("StatusAtFollowUp")]=="Dead",1,0)

Gdata[is.na(Gdata)]<-mean(Gdata,na.rm=T)

#generate some prognostic factors
nPatients<-ncol(Gdata)
ProgFact<-data.frame(Age=floor(SurvTime*0.68+rnorm(nPatients,30,10)),
		Stage=sample(1:4,nPatients,replace=T),sex=rbinom(nPatients, 1, 0.5))


###################################################
### code chunk number 4: aBioMarVsuit.Rnw:104-111 (eval = FALSE)
###################################################
## SimData<-GenSynSurvData(nPatients=100,nGenes=150,Pi=0.5)
## 
## SurvTime<-SimData$SurvTime
## Censor<-SimData$Censor
## ProgFact<-SimData$ProgFact
## Gdata<-SimData$Gdata
## featurenames<-SimData$featurenames


###################################################
### code chunk number 5: aBioMarVsuit.Rnw:120-121 (eval = FALSE)
###################################################
## EstimHR(RiskScore, Sdata, ProgFact = NULL, Plots = FALSE, MedianCut = NULL)


###################################################
### code chunk number 6: aBioMarVsuit.Rnw:131-137
###################################################
results1<-SurFitPlsClasif(SurvTime, Gdata,  Censor, ReduceDim=TRUE, NuFeToBeSel=100,
		ProgFact=NULL, Plots = FALSE,MedianCut = NULL )

#Estimated HR for low risk group
summary(results1$SurFit)[[8]][-2]



###################################################
### code chunk number 7: Plsfig
###################################################
plot(survfit(results1$SurFit,newdata=data.frame(gid=as.factor(c("low","high")))),col=3:2,
		main="Fitted Survival Curves [PLS]",xlab="Time",ylab="Probability")
legend("topright",c("Low risk","High Risk"),col=3:2,lty=c(1,1))


###################################################
### code chunk number 8: aBioMarVsuit.Rnw:149-152 (eval = FALSE)
###################################################
## results1<-SurFitPcaClasif(SurvTime, Gdata, Censor, ReduceDim=TRUE, NuFeToBeSel=100,
##                         ProgFact=NULL,  Plots = FALSE,      MedianCut = NULL )
## summary(results1$SurFit)


###################################################
### code chunk number 9: aBioMarVsuit.Rnw:159-164
###################################################
Ana1<-GeneSpecificCoxPh( SurvTime, Gdata, Censor,  ReduceDim=TRUE, NuFeToBeSel=50,
                        ProgFact=NULL,  MedianCut = NULL)

show(Ana1)
summary(Ana1)


###################################################
### code chunk number 10: gSpefig
###################################################
plot(Ana1)


###################################################
### code chunk number 11: MvFig
###################################################
MVres<-MajorityVotes(Ana1,ProgFact=NULL, SurvTime,Censor,J=1)


###################################################
### code chunk number 12: gridFig
###################################################
GridAnalysis(SurvTime,Gdata,Censor,ReduceDim=TRUE, NuFeToBeSel=150, 
ProgFact=NULL, Plots = TRUE,DimMethod="PLS")


###################################################
### code chunk number 13: aBioMarVsuit.Rnw:188-190 (eval = FALSE)
###################################################
## GridAnalysis(SurvTime,Gdata,Censor,ReduceDim=TRUE, NuFeToBeSel=150, 
## ProgFact=NULL, Plots = TRUE,DimMethod="PCA")


###################################################
### code chunk number 14: aBioMarVsuit.Rnw:196-208
###################################################
data(exprLym)

GexprMatrix<-exprs(exprLym)
SurvData<-pData(exprLym)

PatietId<-rownames(SurvData[!is.na(SurvData[,c("IPI")]),])
Gdata<-GexprMatrix[,PatietId]

SurvTime<-SurvData[!is.na(SurvData[,c("IPI")]),c("FollowUpYears")]
Censor<-ifelse(SurvData[!is.na(SurvData[,c("IPI")]),c("StatusAtFollowUp")]=="Dead",1,0)

Gdata[is.na(Gdata)]<-mean(Gdata,na.rm=T)


###################################################
### code chunk number 15: seInFig
###################################################
SeqIncreaseGenes(TopK=15,SurvTime=SurvTime,Gdata=Gdata,Censor=Censor,ReduceDim=TRUE, 
NuFeToBeSel=150, ProgFact=NULL, Plots = TRUE,DimMethod="PLS")


###################################################
### code chunk number 16: aBioMarVsuit.Rnw:218-225
###################################################
set.seed(123)
Perm<-NullDistHR(n.perm=50,case=2, Validation="PLSbased", SurvTime, Gdata,
                        Censor,  ReduceDim=TRUE,  NuFeToBeSel=150,
                        ProgFact=NULL,  MedianCut = NULL )
show(Perm)

summary(Perm)


###################################################
### code chunk number 17: NullDisfig
###################################################
plot(Perm)


###################################################
### code chunk number 18: aBioMarVsuit.Rnw:235-242
###################################################
NuFeToBeSel=50
DataForReduction<-list(x=Gdata,y=SurvTime, censoring.status=Censor, 
		featurenames=rownames(Gdata))
TentativeList<-names(sort(abs(superpc.train(DataForReduction, 
type="survival")$feature.scores),decreasing =TRUE))[1:NuFeToBeSel]
               
ReduGdata<-Gdata[TentativeList,]


###################################################
### code chunk number 19: LassoFig
###################################################
set.seed(145)
L1<-LassoElasticNetCoxPh(SurvTime,Censor,ReduGdata[1:50,], ProgFact=NULL, Plots = TRUE, 
                     MedianCut = NULL , GeneList=NULL,
                        StZ=TRUE,  alpha=1)
summary(L1$Results$SurFit)				


###################################################
### code chunk number 20: aBioMarVsuit.Rnw:263-267 (eval = FALSE)
###################################################
## R1<-CVforDimPcaPls(fold=3,SurvTime, Gdata, Censor,  ReduceDim=TRUE,
##                         NuFeToBeSel=150, ProgFact=ProgFact,
##                         Plots = FALSE,  n=50 ,  DR ="PLS", mtitle="")
## show(R1)    


###################################################
### code chunk number 21: aBioMarVsuit.Rnw:269-270 (eval = FALSE)
###################################################
## plot(R1,ylim=c(0,5))


###################################################
### code chunk number 22: aBioMarVsuit.Rnw:275-277 (eval = FALSE)
###################################################
## cvmvres<-CvForMajorityVotes(SurvTime,Censor, ProgFact=NULL, Gdata, ReduceDim=TRUE,
## 		NuFeToBeSel=50, fold=3, nCV=50)


###################################################
### code chunk number 23: aBioMarVsuit.Rnw:280-282
###################################################
pathdata<-system.file("doc/extdata",package = "aBioMarVsuit")
load(paste(pathdata,"/cvmvres.RData",sep=""))


###################################################
### code chunk number 24: aBioMarVsuit.Rnw:285-286
###################################################
show(cvmvres)


###################################################
### code chunk number 25: CVmvfig
###################################################
plot(cvmvres)


###################################################
### code chunk number 26: aBioMarVsuit.Rnw:297-301 (eval = FALSE)
###################################################
## CVR1<-CVGeneSpecificCoxPh(fold=3, SurvTime, Gdata, Censor,
##                         ReduceDim=TRUE,  NuFeToBeSel=50,
##                         ProgFact=NULL, MedianCut = NULL,
##                         n.cv=50)


###################################################
### code chunk number 27: aBioMarVsuit.Rnw:304-306
###################################################
pathdata<-system.file("doc/extdata",package = "aBioMarVsuit")
load(paste(pathdata,"/CVgbyg.RData",sep=""))


###################################################
### code chunk number 28: aBioMarVsuit.Rnw:310-313
###################################################
show(CVR1)                         

summary(CVR1, Which=20)


###################################################
### code chunk number 29: CVgbygFig
###################################################
plot(CVR1, Which=20,ylim=c(0,5))


###################################################
### code chunk number 30: GeneOcuFig
###################################################
res<-GeneOccurence(CVR1,TopK=20,minFreq=5)


###################################################
### code chunk number 31: aBioMarVsuit.Rnw:338-341 (eval = FALSE)
###################################################
## CVTopK<-CVSeqIncreaseGenes(CVR1,top=seq(5,100,by=5),SurvTime,Censor, ProgFact=NULL)
## plot(CVTopK)
## summary(CVTopK)


###################################################
### code chunk number 32: aBioMarVsuit.Rnw:354-360 (eval = FALSE)
###################################################
## #Without Prognostic Factors
## set.seed(123) 
## CVres<-CVLassoElasticNetCoxPh(n.cv=50,fold=3,SurvTime, Censor, Gdata, 
## 		NuFeToBeSel=100, ProgFact=NULL, 
##        ReduceDim=TRUE, GeneList=NULL,  StZ=TRUE, alpha=1)
##                          


###################################################
### code chunk number 33: aBioMarVsuit.Rnw:363-365
###################################################
pathdata<-system.file("doc/extdata",package = "aBioMarVsuit")
load(paste(pathdata,"/CVres.RData",sep=""))


###################################################
### code chunk number 34: aBioMarVsuit.Rnw:369-371
###################################################
show(CVres)
summary(CVres)


###################################################
### code chunk number 35: CVL1Fig1
###################################################
#distribution of the HR
plot(CVres,ptype=1)


###################################################
### code chunk number 36: CVL1Fig2
###################################################
#estimated HR vs number of genes selected
plot(CVres,ptype=2)


###################################################
### code chunk number 37: CVL1Fig3
###################################################
#Mostly selected 30 genes
plot(CVres,ptype=3)


###################################################
### code chunk number 38: aBioMarVsuit.Rnw:393-397 (eval = FALSE)
###################################################
## set.seed(123) 
## ElNet<-CVLassoElasticNetCoxPh(n.cv=20,fold=3,SurvTime, 
##   Censor, Gdata, NuFeToBeSel=150, ProgFact=NULL, 
##   ReduceDim=TRUE, GeneList=NULL,  StZ=TRUE, alpha=0.2)


###################################################
### code chunk number 39: aBioMarVsuit.Rnw:402-403
###################################################
grid.alpha<-seq(0.1,0.9,by=0.1)


###################################################
### code chunk number 40: aBioMarVsuit.Rnw:406-433 (eval = FALSE)
###################################################
## set.seed(123) 
## 
## CvElNetResults<-sapply(grid.alpha, 
## 		function(alpha) CVLassoElasticNetCoxPh(n.cv=50,fold=3,SurvTime, 
##                             Censor, Gdata, NuFeToBeSel=100, ProgFact=NULL, 
##                              ReduceDim=TRUE, GeneList=NULL,  StZ=TRUE, 
##                              alpha=alpha))
## 
## #extract slots from S4 Class objects
## Runtime<-sapply(1:length(grid.alpha),
## 		function(k) slot(CvElNetResults[[k]], "Run.Time"))
## lambda <-sapply(1:length(grid.alpha),
## 		function(k) slot(CvElNetResults[[k]], "lambda"))
## n.g    <-sapply(1:length(grid.alpha),
## 		function(k) slot(CvElNetResults[[k]], "n.g"))
## HRT    <-sapply(1:length(grid.alpha), 
## 		function(k) slot(CvElNetResults[[k]], "HRT")[,1] )
## HRTE   <-sapply(1:length(grid.alpha), 
## 		function(k) slot(CvElNetResults[[k]], "HRTE")[,1] )
## HRTm   <-t(sapply(1:length(grid.alpha),
## 				function(k) quantile(slot(CvElNetResults[[k]], "HRT")[,1],
##          na.rm=T,probs = c(0.025,0.5,0.975))))
## HRTEm  <-t(sapply(1:length(grid.alpha),
## 				function(k) quantile(slot(CvElNetResults[[k]], "HRTE")[,1],
##          na.rm=T,probs = c(0.025,0.5,0.975)))) 
## freq   <-sapply(1:length(grid.alpha), 
## 		function(k) colSums(slot(CvElNetResults[[k]], "gene.mat")))


###################################################
### code chunk number 41: aBioMarVsuit.Rnw:436-438
###################################################
pathdata<-system.file("doc/extdata",package = "aBioMarVsuit")
load(paste(pathdata,"/CvElNetResults.RData",sep=""))


###################################################
### code chunk number 42: CVELFig1
###################################################
colnames(HRTE)<-grid.alpha
boxplot(HRTE,ylim=c(0,max(HRTE)),names=grid.alpha[1:length(grid.alpha)],
main="HR on Testing Set \n 100 runs",col=2:(length(grid.alpha)+1),ylab="HR",
xlab=expression(alpha),cex.main=1.5,cex.lab=1.3)


###################################################
### code chunk number 43: aBioMarVsuit.Rnw:462-492 (eval = FALSE)
###################################################
## #Select Top K genes (Mostly selected genes during the CV)
##  TopGenes<-c("TPRT(23590)", "COL19A1(1310)","RPL7L1(285855)","DMD(1756)", "NR3C1(2908)",
##  "ITGA6(3655)", "PRKD1(5587)","IFRD1(3475)","BMP6(654)","SFXN4(119559)","TOPBP1(11073)" 
##  ,"LILRA4(23547)", "DNTTIP2(30836)" , "HBS1L(10767)"  ,  "MUS81(80198)")
## 
## #Example I-----------------------------------------
## # without prognostic factors and Weights are updated
## 
## WOpWup<-InnerCrossValELNet(fold=3,n.cv=20,n.innerCV=50,MixParAlpha=1,
##                              Gdata,TopGenes,WeightsFixed=FALSE,
##                              SurvTime, Censor,ProgFact=NULL)
## show(WOpWup)
## summary(WOpWup)
## 
## #Example II-----------------------------------------                             
## #with prognostic factors 
## #and Weights are fixed
##                              
## WpWFtrue<-InnerCrossValELNet(fold=3,n.cv=20,n.innerCV=50,MixParAlpha=1,
##                              Gdata,TopGenes,WeightsFixed=TRUE,
##                              SurvTime, Censor,ProgFact)
## show(WpWFtrue)
## summary(WpWFtrue)   
## 
## #and Weights are NOT fixed
## WpWFfalse<-InnerCrossValELNet(fold=3,n.cv=20,n.innerCV=50,MixParAlpha=1,
##                              Gdata,TopGenes,WeightsFixed=FALSE,
##                              SurvTime, Censor,ProgFact)
## show(WpWFfalse)
## summary(WpWFfalse)                            


###################################################
### code chunk number 44: aBioMarVsuit.Rnw:495-497
###################################################
pathdata<-system.file("doc/extdata",package = "aBioMarVsuit")
load(paste(pathdata,"/InnerCvElNetResults.RData",sep=""))


###################################################
### code chunk number 45: InnerCVL1Fig1
###################################################
plot(WpWFtrue,ptype=1)	


###################################################
### code chunk number 46: aBioMarVsuit.Rnw:506-516 (eval = FALSE)
###################################################
## # compare results based on classifier with fixed weights versus classifier with weights 
## # changing and final classification based on majority votes
## 
## # estimated HR at each iteration for weights NOT fixed
## Res<-data.frame(HRTrue=slot(WpWFtrue, "HRTE")[,1],HRfalse=slot(WpWFfalse, "HRTE")[,1])
## boxplot(Res,col="red",ylim=c(0,1),main="Estimated HR based on completely
## independent Samples",names=c("Weights Fixed","Weights Updated"))
## 
## # estimated density of the HR 
## plot(WpWFtrue,ptype=2)


